package org.mmga.clubs.service;

import org.apache.commons.codec.digest.DigestUtils;
import org.mmga.clubs.dao.UserDao;
import org.mmga.clubs.entities.BaseResponse;
import org.mmga.clubs.entities.user.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class UserService {
    private final UserDao userDao;
    private final AuthService authService;
    @Autowired
    public UserService(UserDao userDao, AuthService authService){
        this.userDao = userDao;
        this.authService = authService;
    }

    public BaseResponse<User> login(UserLoginVo user) {
        UserVo userVo = userDao.getUser(user.name(), DigestUtils.sha1Hex(user.password()));
        User u = packageUser(userVo);
        return u == null ? BaseResponse.failed(404, "无效用户") : BaseResponse.success(u);
    }

    public BaseResponse<User> createUser(UserRegVo user) {
        String username = user.username();
        if (userDao.countUser(username) > 0) {
            return BaseResponse.failed(409, "用户已存在");
        }
        UserRegResponseVo response = new UserRegResponseVo(user);
        userDao.addUser(response);
        int newUserId = response.getId();
        return BaseResponse.success(packageUser(userDao.getUserById(newUserId)));
    }
    private User packageUser(UserVo vo) {
        if (vo == null){
            return null;
        }
        User result = new User();
        result.setId(vo.id());
        result.setName(vo.name());
        result.setAuth(authService.getAuthById(vo.auth()));
        return result;
    }
}
